summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAllan Sandfeld Jensen <allan.jensen@qt.io>2018-08-12 14:26:22 +0200
committerAllan Sandfeld Jensen <allan.jensen@qt.io>2018-10-19 12:56:05 +0200
commit34f52ec3bae86fb57837ad68691d548bd0dc9541 (patch)
treec7c8d7055caea4d2f2a3c5e79ca0fb360f0077c8
parent5e3e5074bb78dc9f22220771cdbf6ea25819c241 (diff)
downloadqtwebengine-chromium-34f52ec3bae86fb57837ad68691d548bd0dc9541.tar.gz
Bump maximum number of custom isolated world ids
The real maximum deeper in Chromium is (1<<29), but better not push the limit too much. Task-number: QTBUG-69904 Change-Id: Ie44d444471678cf8281ef7c6fc75fbad0eb8b8bc Reviewed-by: Jüri Valdmann <juri.valdmann@qt.io>
-rw-r--r--chromium/content/public/common/isolated_world_ids.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/chromium/content/public/common/isolated_world_ids.h b/chromium/content/public/common/isolated_world_ids.h
index 271637e1c2a..903c472f2a2 100644
--- a/chromium/content/public/common/isolated_world_ids.h
+++ b/chromium/content/public/common/isolated_world_ids.h
@@ -13,9 +13,9 @@ enum IsolatedWorldIDs {
ISOLATED_WORLD_ID_GLOBAL = 0,
// Custom isolated world ids used by other embedders should start from here.
ISOLATED_WORLD_ID_CONTENT_END,
// If any embedder has more than 10 custom isolated worlds that will be run
// via RenderFrameImpl::OnJavaScriptExecuteRequestInIsolatedWorld update this.
- ISOLATED_WORLD_ID_MAX = ISOLATED_WORLD_ID_CONTENT_END + 10,
+ ISOLATED_WORLD_ID_MAX = ISOLATED_WORLD_ID_CONTENT_END + 255,
};
} // namespace content
@@ -13,9 +13,9 @@ enum IsolatedWorldIDs {
// Custom isolated world ids used by other embedders should start from here.
ISOLATED_WORLD_ID_CONTENT_END,
- // If any embedder has more than 10 custom isolated worlds that will be run
+ // If any embedder has more than 255 custom isolated worlds that will be run
// via RenderFrameImpl::OnJavaScriptExecuteRequestInIsolatedWorld update this.